@@ -22,11 +22,12 @@
                 "pcr", "plsr", "hfr", "boost", "subset", "cor", "bayes", "quantile",
                 "glmm", "tvp", "mslm", "bma", "gets", "svm", "mrmr", "relief", "cor",
                 "chisq", "rf", "bridge", "blasso", "spikeslab", "genetic",
-                "quantile_rf", "anova", "nnet"),
+                "quantile_rf", "anova", "nnet", "group_lasso"),
     message = "'%s' is not a valid method. See '?m' for details"
   ),
   cv = list(
-    methods = c("lasso", "ridge", "enet", "adalasso", "pcr", "plsr", "hfr", "boost", "svm", "rf", "quantile_rf", "nnet"),
+    methods = c("lasso", "ridge", "enet", "adalasso", "pcr", "plsr", "hfr", "boost",
+                "svm", "rf", "quantile_rf", "nnet", "group_lasso"),
     message = "'%s' has no hyperparameters. Use '.force_cv = TRUE' to perform a cross validation"
   ),
   has_predict_method = list(
@@ -34,7 +35,7 @@
                 "pcr", "plsr", "hfr", "boost", "subset", "bayes", "quantile",
                 "glmm", "tvp", "mslm", "bma", "gets", "svm",
                 "rf", "bridge", "blasso", "spikeslab", "genetic",
-                "quantile_rf", "nnet"),
+                "quantile_rf", "nnet", "group_lasso"),
     message = "'%s' has no predict method."
   ),
   uses_index = list(
@@ -45,12 +46,12 @@
     methods = c("lm", "glm", "robust", "lasso", "ridge", "enet", "adalasso",
                 "pcr", "plsr", "hfr", "boost", "subset", "cor", "bayes", "quantile",
                 "glmm", "tvp", "mslm", "bma", "gets", "svm", "mrmr", "relief", "cor", "rf", "bridge", "blasso",
-                "spikeslab", "genetic", "quantile_rf", "anova", "nnet"),
+                "spikeslab", "genetic", "quantile_rf", "anova", "nnet", "group_lasso"),
     message = "'%s' cannot be used for regression"
   ),
   classify = list(
     methods = c("glm", "lasso", "ridge", "enet", "adalasso", "boost", "subset", "bayes", "glmm", "svm", "mrmr",
-                "relief", "chisq", "rf", "spikeslab", "anova", "nnet"),
+                "relief", "chisq", "rf", "spikeslab", "anova", "nnet", "group_lasso"),
     message = "'%s' cannot be used for classification"
   ),
   multinomial = list(
@@ -62,14 +63,15 @@
     message = "'%s' uses non-standard formula syntax"
   ),
   has_importance_method = list(
-    methods = c("lm", "glm", "lasso", "ridge", "enet", "adalasso", "rf", "quantile_rf", "subset", "gets", "nnet"),
+    methods = c("lm", "glm", "lasso", "ridge", "enet", "adalasso", "rf", "quantile_rf",
+                "subset", "gets", "nnet", "hfr", "pcr", "plsr", "bayes"),
     message = "'%s' has no variable importance method"
   ),
   has_coef_method = list(
     methods = c("lm", "glm", "robust", "lasso", "ridge", "enet", "adalasso",
                 "pcr", "plsr", "hfr", "boost", "subset", "cor", "bayes", "quantile",
                 "glmm", "tvp", "mslm", "bma", "gets", "svm", "mrmr", "relief", "cor",
-                "chisq", "bridge", "blasso", "spikeslab", "genetic", "anova"),
+                "chisq", "bridge", "blasso", "spikeslab", "genetic", "anova", "group_lasso"),
     message = "'%s' has not coef method"
   )
 )
